@@ -57,7 +57,7 @@ class Request():
 
     def post(self, payload, headers, text_response=True):
         try:
-            if (isRetry(self)):
+            if (self.isRetry(self)):
                 data = requests.post(
                     "http://pwbus-http/pwbus/v1/retry",
                     data={},
